==> question2answer-1.3-language-ru.zip: ru/qa-lang-main.php <==
<?php
	
/*
	Question2Answer 1.3 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-lang-main.php
	Version: 1.3
	Date: 2010-11-27 12:12:11 GMT
	Description: Language phrases commonly used throughout Q2A, plus a few other misc ones


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 ответ',
		'1_day' => '1 день',
		'1_disliked' => '1 непохожий',
		'1_hour' => '1 час',
		'1_liked' => '1 похожий',
		'1_minute' => '1 минута',
		'1_month' => '1 месяц',
		'1_point' => '1 балл',
		'1_question' => '1 вопрос',
		'1_second' => '1 секунда',
		'1_vote' => '1 голос',
		'1_week' => '1 неделя',
		'1_year' => '1 год',
		'all_categories' => 'Все категории',
		'anonymous' => 'незарегистрированного пользователя',
		'answered' => 'Ответ',
		'answer_edited' => 'Редактирование ответа',
		'asked' => 'Вопрос',
		'by_x' => 'от ^',
		'cancel_button' => 'Отменить',
		'commented' => 'Комментарий',
		'comment_edited' => 'Редактирование комментария',
		'edited' => 'Редактирование',
		'field_required' => 'Пожалуйста, напишите в этом поле',
		'general_error' => 'Произошла ошибка сервера - пожалуйста, попробуйте еще раз.',
		'highest_users' => 'Топ лучших пользователей',
		'in_category_x' => 'в категории ^',
		'ip_address_x' => 'IP-адрес ^',
		'logged_in_x' => 'Здравствуйте, ^!',
		'max_length_x' => 'Максимальная длина - ^ символов',
		'me' => 'меня',
		'meta_order' => '^what^when^who^where', // sets order of elements like: <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Пожалуйста, добавьте больше информации (как минимум ^ символов)',
		'nav_account' => 'Мой профиль',
		'nav_activity' => 'Новое',
		'nav_admin' => 'Админ',
		'nav_ask' => 'Задать вопрос',
		'nav_categories' => 'Категории',
		'nav_feedback' => 'Отправить отзыв',
		'nav_home' => 'Главная',
		'nav_login' => 'Вход',
		'nav_logout' => 'Выход',
		'nav_qa' => 'ВиО',
		'nav_qs' => 'Вопросы',
		'nav_register' => 'Регистрация',
		'nav_tags' => 'Теги',
		'nav_unanswered' => 'Без ответов',
		'nav_users' => 'Пользователи',
		'no_active_users' => 'Активных пользователей не найдено',
		'no_answers_found' => 'Ответов не найдено',
		'no_answers_in_x' => 'Нет ответов в категории ^',
		'no_categories_found' => 'Категории не найдено',
		'no_category' => 'Нет категории',
		'no_comments_found' => 'Комментариев не найдено',
		'no_comments_in_x' => 'Нет комментариев в категории ^',
		'no_questions_found_in_x' => 'Вопросов не найдено в категории ^',
		'no_questions_found' => 'Вопросов не найдено',
		'no_related_qs_title' => 'Связанных вопросов не найдено',
		'no_results_for_x' => 'Нет результатов для ^',
		'no_tags_found' => 'Тегов не найдено',
		'no_una_questions_found' => 'Нет вопросов без ответа',
		'no_una_questions_in_x' => 'Нет вопросов без ответа в категории ^',
		'page_label' => 'Страница:',
		'page_next' => 'вперёд',
		'page_not_found' => 'Страница не найдена',
		'page_prev' => 'назад',
		'popular_tags' => 'Популярные теги',
		'questions_tagged_x' => 'Вопросы с тегом ^',
		'recent_activity_in_x' => 'Последние действия в категории ^',
		'recent_activity_title' => 'Последние действия',
		'recent_as_in_x' => 'Последние отвеченные вопросы в категории ^',
		'recent_as_title' => 'Последние отвеченные вопросы',
		'recent_cs_in_x' => 'Последние комментарии в категории ^',
		'recent_cs_title' => 'Последние комментарии',
		'recent_qs_as_in_x' => 'Последние вопросы и ответы в категории ^',
		'recent_qs_as_title' => 'Последние вопросы и ответы',
		'recent_qs_in_x' => 'Все вопросы в категории ^',
		'recent_qs_title' => 'Все вопросы',
		'related_qs_title' => 'Похожие вопросы',
		'results_for_x' => 'Результаты поиска для ^',
		'save_button' => 'Сохранить изменения',
		'search_button' => 'Поиск',
		'search_title' => 'Поиск вопросов',
		'send_button' => 'Отправить',
		'suggest_ask' => 'Начать, ^1 задав вопрос ^2',
		'suggest_category_qs' => 'Для получения более полной информации посмотрите ^1все вопросы в этой категории^2.',
		'suggest_qs_tags' => 'Для получения более полной информации посмотрите в ^1списке вопросов^2 или в ^3популярных тегах^4.',
		'suggest_qs' => 'Для получения более полной информации посмотрите ^1список вопросов^2.',
		'unanswered_qs_in_x' => 'Вопросы без ответов в категории ^',
		'unanswered_qs_title' => 'Вопросы без ответов',
		'vote_disabled_hidden_a' => 'Вы не можете голосовать за скрытые ответы',
		'vote_disabled_hidden_q' => 'Вы не можете голосовать за скрытые вопросы',
		'vote_disabled_q_page_only' => 'Пожалуйста, просмотрите этот вопрос, чтобы проголосовать',
		'vote_disabled_my_a' => 'Вы не можете голосовать за свои ответы',
		'vote_disabled_my_q' => 'Вы не можете голосовать за свои вопросы',
		'vote_down_popup' => 'Нажмите, чтобы проголосовать ПРОТИВ',
		'vote_limit' => 'От вас поступило слишком много голосов - попробуйте в следующем часе',
		'vote_must_confirm' => 'Подтвердите ^5адрес эл. почты^6, чтобы голосовать.',
		'vote_must_login' => 'Пожалуйста, ^1войдите^2 или ^3зарегистрируйтесь^4, чтобы голосовать',
		'vote_not_allowed' => 'За это нельзя голосовать',
		'vote_up_popup' => 'Нажмите, чтобы проголосовать ЗА',
		'voted_down_popup' => 'Вы голосовали ПРОТИВ - нажмите, чтобы отменить',
		'voted_up_popup' => 'Вы голосовали ЗА - нажмите, чтобы отменить',
		'x_ago' => '^ назад',
		'x_answers' => '^ ответов',
		'x_days' => '^ дней',
		'x_disliked' => '^ непохожих',
		'x_hours' => '^ часов',
		'x_liked' => '^ похожих',
		'x_minutes' => '^ минут',
		'x_months' => '^ месяцев',
		'x_points' => '^ баллов',
		'x_questions' => '^ вопросов',
		'x_seconds' => '^ секунд',
		'x_votes' => '^ голосов',
		'x_weeks' => '^ недель',
		'x_years' => '^ года',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.4-language-ru.zip: ru/qa-lang-main.php <==
<?php
	
/*
    Question2Answer 1.4.1 (c) 2011, Gideon Greenspan

	http://www.question2answer.org/

    File: qa-lang/ru/qa-lang-main.php
	Version: 1.4.1
	Date: 2011-08-20
	Description: Русификация Question2Answer 1.4
	Translation: Starozhuk Anatoliy / http://facknet.ru/ 

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 ответ',
		'1_comment' => '1 комментарий',
		'1_day' => '1 день',
		'1_disliked' => '1 непохожий',
		'1_flag' => '1 признак',
		'1_hour' => '1 час',
		'1_liked' => '1 похожий',
		'1_minute' => '1 минуту',
		'1_month' => '1 месяц',
		'1_point' => '1 балл',
		'1_question' => '1 вопрос',
		'1_second' => '1 секунду',
		'1_user' => '1 пользователь',
		'1_view' => '1 просмотр',
		'1_vote' => '1 голос',
		'1_week' => '1 неделю',
		'1_year' => '1 год',
		'all_categories' => 'Все категории',
		'anonymous' => 'незарегистрированного пользователя',
		'answer_edited' => 'ответ отредактирован',
		'answered_qs_title' => 'Большинство ответов на вопросы',
		'answered' => 'Ответ',
		'asked' => 'Спросили',
		'by_x' => 'от ^',
		'cancel_button' => 'Отменить',
		'commented' => 'Комментарий',
		'comment_edited' => 'Редактирование комментария',
		'edited' => 'Редактирование',
		'field_required' => 'Пожалуйста, напишите в этом поле',
		'general_error' => 'Произошла ошибка сервера - пожалуйста, попробуйте еще раз.',
		'highest_users' => 'Топ лучших пользователей',
		'hot_qs_title' => 'Горячие вопросы',
		'voted_qs_title'  => 'Больше голосов',
		'image_not_read' => 'Изображение не может быть показано. Загрузите его: ^',
		'image_too_big_x_pc' => 'Это изображение является слишком большой. Пожалуйста, масштаб ^% попробуйте еще раз.',
		'in_category_x' => 'в категории ^',
		'ip_address_x' => 'IP-адрес ^',
		'logged_in_x' => 'Здравствуйте, ^!',
		'max_length_x' => 'Максимальная длина - ^ символов',
		'me' => 'меня',
		'meta_order' => '^what^when^where^who!', // sets order of elements like: <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Пожалуйста, добавьте больше информации (как минимум ^ символов)',
		'nav_account' => 'Мой профиль',
		'nav_activity' => 'Новое',
		'nav_admin' => 'Админ',
		'nav_ask' => 'Задать вопрос',
		'nav_categories' => 'Категории',
		'nav_feedback' => 'Отправить отзыв',
		'nav_home' => 'Главная',
		'nav_hot' => 'Горячие!',
		'nav_login' => 'Вход',
		'nav_logout' => 'Выход',
		'nav_most_answers' => '> ответов',
		'nav_most_recent' => 'Последние',
		'nav_most_views' => '> просмотров',
		'nav_most_votes' => '> голосов',
		'nav_qa' => 'Q&A CMS',
		'nav_qs' => 'Вопросы',
        'nav_register' => 'Регистрация',
		'nav_tags' => 'Теги',
		'nav_unanswered' => 'Без ответов',
		'nav_users' => 'Пользователи',
		'no_active_users' => 'Активных пользователей не найдено',
		'no_answers_found' => 'Ответов не найдено',
		'no_answers_in_x' => 'Нет ответов в категории ^',
		'no_categories_found' => 'Категории не найдено',
		'no_category' => 'Нет категории',
		'no_comments_found' => 'Комментариев не найдено',
		'no_comments_in_x' => 'Нет комментариев в категории ^',
		'no_questions_found' => 'Вопросов не найдено',
		'no_related_qs_title' => 'Связанных вопросов не найдено',
		'no_results_for_x' => 'Нет результатов для ^',
		'no_tags_found' => 'Тегов не найдено',
		'no_una_questions_found' => 'Нет вопросов без ответа',
		'page_label' => 'Страница:',
		'page_next' => 'вперёд',
		'page_not_found' => 'Страница не найдена',
		'page_prev' => 'назад',
		'popular_tags' => 'Популярные теги',
		'questions_tagged_x' => 'Вопросы с тегом ^',
		'recent_activity_in_x' => 'Последние действия в категории ^',
		'recent_activity_title' => 'Последние действия',
		'recent_as_in_x' => 'Последние отвеченные вопросы в категории ^',
		'recent_as_title' => 'Последние отвеченные вопросы',
		'recent_cs_in_x' => 'Последние комментарии в категории ^',
		'recent_cs_title' => 'Последние комментарии',
		'recent_qs_as_in_x' => 'Последние вопросы и ответы в категории ^',
		'recent_qs_as_title' => 'Последние вопросы и ответы',
		'recent_qs_in_x' => 'Все вопросы в категории ^',
		'recent_qs_title' => 'Последние вопросы',
		'related_qs_title' => 'Похожие вопросы',
		'results_for_x' => 'Результаты поиска для ^',
		'save_button' => 'Сохранить изменения',
		'search_button' => 'Поиск',
		'search_title' => 'Поиск вопросов',
		'send_button' => 'Отправить',
		'suggest_ask' => 'Начать, ^1 задав вопрос ^2',
		'suggest_category_qs' => 'Для получения более полной информации посмотрите ^1все вопросы в этой категории^2.',
		'suggest_qs_tags' => 'Для получения более полной информации посмотрите в ^1списке вопросов^2 или в ^3популярных тегах^4.',
		'suggest_qs' => 'Для получения более полной информации посмотрите ^1список вопросов^2.',
		'unanswered_qs_in_x' => 'Вопросы без ответов в категории ^',
		'unanswered_qs_title' => 'Вопросы без ответов',
		'upload_limit' => 'Слишком много добавления - попробуйте еще раз через 5 минут',
		'view_q_must_confirm' => 'Пожалуйста, ^5подтвердите свой адрес электронной почты,^6 для просмотра вопрос страниц.',
		'view_q_must_login' => 'Пожалуйста ^1войдите^2 или ^3зарегестрируйтесь^4 Для просмотра страницы вопросов.',
		'viewed_qs_title' => 'Самые популярные вопросы',
		'vote_disabled_hidden_a' => 'Вы не можете голосовать за скрытые ответы',
		'vote_disabled_hidden_q' => 'Вы не можете голосовать за скрытые вопросы',
		'vote_disabled_level' => 'Голосование доступно только для некоторых пользователей',
		'vote_disabled_my_a' => 'Вы не можете голосовать за свои ответы',
		'vote_disabled_my_q' => 'Вы не можете голосовать за свои вопросы',
		'vote_disabled_q_page_only' => 'Пожалуйста, просмотрите этот вопрос, чтобы проголосовать',
		'vote_down_popup' => 'Нажмите, чтобы проголосовать против',
		'vote_limit' => 'От вас поступило слишком много голосов - попробуйте в следующем часе',
		'vote_must_confirm' => 'Подтвердите ^5адрес эл. почты^6, чтобы голосовать.',
		'vote_must_login' => 'Пожалуйста, ^1войдите^2 или ^3зарегистрируйтесь^4, чтобы голосовать',
		'vote_not_allowed' => 'За это нельзя голосовать',
		'vote_up_popup' => 'Нажмите, чтобы проголосовать ЗА',
		'voted_down_popup' => 'Вы голосовали ПРОТИВ - нажмите, чтобы отменить',
		'voted_up_popup' => 'Вы голосовали ЗА - нажмите, чтобы отменить',
		'x_ago' => '^ назад',
		'x_answers' => '^ ответов',
		'x_comments' => '^ комментариев',
		'x_days' => '^ дней',
		'x_disliked' => '^ непохожих',
		'x_flags' => '^ флаглв',
		'x_hours' => '^ часов',
		'x_liked' => '^ похожих',
		'x_minutes' => '^ минут',
		'x_months' => '^ месяцев',
		'x_points' => '^ баллов',
		'x_questions' => '^ вопросов',
		'x_seconds' => '^ секунд',
		'x_users' => '^ пользователей',
		'x_views' => '^ просмотров',
		'x_votes' => '^ голосов',
		'x_weeks' => '^ недель',
		'x_years' => '^ лет',
		'no_questions_in_x' => 'Нет вопросов в категории: ^',
		
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
